pub enum InjectionLanguageMarker<'a> {
Name(&'a str),
Match(RopeSlice<'a>),
Filename(RopeSlice<'a>),
Shebang(RopeSlice<'a>),
}Expand description
An indicator in the document or query source file which used by the loader to know which language an injection should use.
For example if a query sets a property (#set! injection.language "rust") then the loader
should load the Rust language. Alternatively the loader might be asked to load a language
based on some text in the document, for example a markdown code fence language name.
Variants
Name(&'a str)
The language is specified by name in the injection query itself.
For example (#set! injection.language "rust"). These names should match exactly and so
they can be looked up by equality - very efficiently.
Match(RopeSlice<'a>)
The language is specified by name - or similar - within the parsed document.
This is slightly different than the ExactName variant: within a document you might
specify Markdown as “md” or “markdown” for example. The loader should look up the language
name by longest matching regex.
Filename(RopeSlice<'a>)
Shebang(RopeSlice<'a>)