LayerData

Struct LayerData 

pub struct LayerData {
    pub language: Language,
    /* private fields */
}

Fields

language: Language

Implementations

Source

impl LayerData

pub fn tree(&self) -> Option<&Tree>

Returns the parsed Tree for this layer.

This Option will always be Some when the LanguageLoader passed to Syntax::new returns Some when passed the layer’s language in LanguageLoader::get_config.

pub fn injection_at_byte_idx(&self, idx: u32) -> Option<&Injection>

Returns the injection range within this layers that contains idx. This function will not descend into nested injections

pub fn injections_at_byte_idx( &self, idx: u32, ) -> impl Iterator<Item = &Injection>

Returns the injection ranges within this layers that contain idx or start after idx. This function will not descend into nested injections.