Struct Syntax

pub struct Syntax { /* private fields */ }
The Tree sitter syntax tree for a single language.

This is really multiple (nested) different syntax trees due to tree sitter injections. A single syntax tree/parser is called layer. Each layer is parsed as a single “file” by tree sitter. There can be multiple layers for the same language. A layer corresponds to one of three things:

  • the root layer
  • a singular injection limited to a single node in its parent layer
  • Multiple injections (multiple disjoint nodes in parent layer) that are parsed as though they are a single uninterrupted file.

An injection always refer to a single node into which another layer is injected. As injections only correspond to syntax tree nodes injections in the same layer do not intersect. However, the syntax tree in a an injected layer can have nodes that intersect with nodes from the parent layer. For example:

layer2: | Sibling A |      Sibling B (layer3)     | Sibling C |
layer1: | Sibling A (layer2) | Sibling B | Sibling C (layer2) |

In this case Sibling B really spans across a “GAP” in layer2. While the syntax node can not be split up by tree sitter directly, we can treat Sibling B as two separate injections. That is done while parsing/running the query capture. As a result the injections form a tree. Note that such other queries must account for such multi injection nodes.

Implementations

Source

impl Syntax

pub fn update( &mut self, source: RopeSlice<'_>, timeout: Duration, edits: &[InputEdit], loader: &impl LanguageLoader, ) -> Result<(), Error>

Source

impl Syntax

pub fn new( source: RopeSlice<'_>, language: Language, timeout: Duration, loader: &impl LanguageLoader, ) -> Result<Self, Error>

pub fn layer(&self, layer: Layer) -> &LayerData

pub fn root(&self) -> Layer

pub fn tree(&self) -> &Tree

pub fn tree_for_byte_range(&self, start: u32, end: u32) -> &Tree

pub fn named_descendant_for_byte_range( &self, start: u32, end: u32, ) -> Option<Node<'_>>

pub fn descendant_for_byte_range( &self, start: u32, end: u32, ) -> Option<Node<'_>>

pub fn layer_for_byte_range(&self, start: u32, end: u32) -> Layer

Finds the smallest injection layer that fully includes the range start..=end.

pub fn layers_for_byte_range( &self, start: u32, end: u32, ) -> impl Iterator<Item = Layer> + '_

Returns an iterator of layers which fully include the byte range start..=end, in decreasing order based on the size of each layer.

The first layer is always the root layer.

pub fn walk(&self) -> TreeCursor<'_>