Struct TreeCursor

pub struct TreeCursor<'tree> { /* private fields */ }

Implementations

Source

impl<'tree> TreeCursor<'tree>

pub fn node(&self) -> Node<'tree>

pub fn goto_parent(&mut self) -> bool

pub fn goto_parent_with<P>(&mut self, predicate: P) -> bool
where P: Fn(&Node<'_>) -> bool,

pub fn goto_first_child(&mut self) -> bool

pub fn goto_next_sibling(&mut self) -> bool

pub fn goto_previous_sibling(&mut self) -> bool

pub fn reset_to_byte_range(&mut self, start: u32, end: u32)

pub fn children<'a>(&'a mut self) -> ChildIter<'a, 'tree>

Returns an iterator over the children of the node the TreeCursor is on at the time this is called.