pub struct TextObjectQuery {
pub query: Query,
}Fields
query: QueryImplementations
Sourceimpl TextObjectQuery
impl TextObjectQuery
Sourcepub fn capture_nodes<'a>(
&'a self,
capture_name: &str,
node: Node<'a>,
slice: RopeSlice<'a>,
cursor: InactiveQueryCursor,
) -> Option<impl Iterator<Item = CapturedNode<'a>>>
pub fn capture_nodes<'a>( &'a self, capture_name: &str, node: Node<'a>, slice: RopeSlice<'a>, cursor: InactiveQueryCursor, ) -> Option<impl Iterator<Item = CapturedNode<'a>>>
Run the query on the given node and return sub nodes which match given capture (“function.inside”, “class.around”, etc).
Captures may contain multiple nodes by using quantifiers (+, *, etc), and support for this is partial and could use improvement.
(comment)+ @capture
; OR
(
(comment)*
.
(function)
) @captureSourcepub fn capture_nodes_any<'a>(
&'a self,
capture_names: &[&str],
node: Node<'a>,
slice: RopeSlice<'a>,
cursor: InactiveQueryCursor,
) -> Option<impl Iterator<Item = CapturedNode<'a>>>
pub fn capture_nodes_any<'a>( &'a self, capture_names: &[&str], node: Node<'a>, slice: RopeSlice<'a>, cursor: InactiveQueryCursor, ) -> Option<impl Iterator<Item = CapturedNode<'a>>>
Find the first capture that exists out of all given capture_names
and return sub nodes that match this capture.